﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Linq;

using IdeaBlade.Core;
using IdeaBlade.EntityModel;
using IdeaBlade.Linq;

using CoreModel;
using LeafModel;

// This solution shows how to access multiple models from a single EntityManager.
// There are two models - CoreModel and LeafModel, which can be sourced from two different
// datasources. In this case, they are both from NorthwindIB, but the code does not know the
// difference.
//
// The models have also been placed into their own assemblies, which is not required,
// but is good practice for larger applications. There are Silverlight versions of the models
// each of which contains a link to the shared source file. When you add any business logic to
// the entities, you should also add links to the partial classes in the Silverlight model assemblies
// so that all of the source is shared.
//
// By default, DevForce generates a typed EntityManager for each model and it contains properties
// for the basic queries for that model. However, any EntityManager can query for entities from
// any model. To do this, create a new EntityQuery of the correct entity type, and then use the
// .With(EntityManager mgr) operator on the query to execute it as shown below.
//
// You can also easily subclass and create your own typed EntityManager with whatever properties
// you need. The code generated EntityManager contains no "magic" and you can use it as a template
// for your own.
// 
// To navigate from one model to another, we suggest using a repository pattern in a third assembly
// to avoid circular references between the models. For example, you would call
// Repository.GetSalesRep(someCustomer) instead of someCustomer.SalesRep.

namespace ManyAssemblyOneManager {
  public class CodeSamples {
    public CodeSamples() {
    }

    public async void Start() {
      var entityManager = new CoreModelEntities();

      // Query for entities from the EntityManager's default model
      var r1 = await entityManager.Customers.ExecuteAsync();
      MessageBox.Show("Customers fetched: " + r1.Count().ToString());

      // Query for entities from a different model
      var query = new EntityQuery<Employee>();
      var r2 = await query.With(entityManager).ExecuteAsync();
      MessageBox.Show("Employees fetched: " + r2.Count().ToString());
    }
  }
}
